Struct ssp::disable::DisableCommand
source · #[repr(C)]pub struct DisableCommand { /* private fields */ }Expand description
Disable - Command (0x09)
This single byte command disables the unit. This means the unit will enter its disabled state and not execute any further commands or perform any other actions. A poll to the unit while in this state will report disabled (0xE8)
Implementations
sourceimpl DisableCommand
impl DisableCommand
sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new DisableCommand message.